==> python3_core_api_client-2.0-py3-none-any.whl: cyberfusion/CoreApiClient/resources/node_add_ons.py <==
from cyberfusion.CoreApiClient import models
from typing import Optional, List

from cyberfusion.CoreApiClient.interfaces import Resource
from cyberfusion.CoreApiClient.http import DtoResponse


class NodeAddOns(Resource):
    def create_node_add_on(
        self,
        request: models.NodeAddOnCreateRequest,
    ) -> DtoResponse[models.TaskCollectionResource]:
        local_response = self.api_connector.send_or_fail(
            "POST",
            "/api/v1/node-add-ons",
            data=request.dict(exclude_unset=True),
            query_parameters={},
        )

        return DtoResponse.from_response(local_response, models.TaskCollectionResource)

    def list_node_add_ons(
        self,
        *,
        skip: Optional[int] = None,
        limit: Optional[int] = None,
        filter_: Optional[List[str]] = None,
        sort: Optional[List[str]] = None,
    ) -> DtoResponse[list[models.NodeAddOnResource]]:
        local_response = self.api_connector.send_or_fail(
            "GET",
            "/api/v1/node-add-ons",
            data=None,
            query_parameters={
                "skip": skip,
                "limit": limit,
                "filter": filter_,
                "sort": sort,
            },
        )

        return DtoResponse.from_response(local_response, models.NodeAddOnResource)

    def get_node_add_on_products(
        self,
    ) -> DtoResponse[list[models.NodeAddOnProduct]]:
        local_response = self.api_connector.send_or_fail(
            "GET", "/api/v1/node-add-ons/products", data=None, query_parameters={}
        )

        return DtoResponse.from_response(local_response, models.NodeAddOnProduct)

    def read_node_add_on(
        self,
        *,
        id_: int,
    ) -> DtoResponse[models.NodeAddOnResource]:
        local_response = self.api_connector.send_or_fail(
            "GET", f"/api/v1/node-add-ons/{id_}", data=None, query_parameters={}
        )

        return DtoResponse.from_response(local_response, models.NodeAddOnResource)

    def delete_node_add_on(
        self,
        *,
        id_: int,
    ) -> DtoResponse[models.DetailMessage]:
        local_response = self.api_connector.send_or_fail(
            "DELETE", f"/api/v1/node-add-ons/{id_}", data=None, query_parameters={}
        )

        return DtoResponse.from_response(local_response, models.DetailMessage)

==> python3_core_api_client-2.4.1-py3-none-any.whl: cyberfusion/CoreApiClient/resources/node_add_ons.py <==
from cyberfusion.CoreApiClient import models
from typing import Optional

from cyberfusion.CoreApiClient.interfaces import Resource
from cyberfusion.CoreApiClient.http import DtoResponse


class NodeAddOns(Resource):
    def create_node_add_on(
        self,
        request: models.NodeAddOnCreateRequest,
        callback_url: Optional[str] = None,
    ) -> DtoResponse[models.TaskCollectionResource]:
        local_response = self.api_connector.send_or_fail(
            "POST",
            "/api/v1/node-add-ons",
            data=request.dict(exclude_unset=True),
            query_parameters={
                "callback_url": callback_url,
            },
        )

        return DtoResponse.from_response(local_response, models.TaskCollectionResource)

    def list_node_add_ons(
        self,
        *,
        page: int = 1,
        per_page: int = 0,
        include_filters: models.NodeAddOnsSearchRequest | None = None,
    ) -> DtoResponse[list[models.NodeAddOnResource]]:
        local_response = self.api_connector.send_or_fail(
            "GET",
            "/api/v1/node-add-ons",
            data=None,
            query_parameters={
                "page": page,
                "per_page": per_page,
            }
            | include_filters.dict(exclude_unset=True)
            if include_filters
            else None,
        )

        return DtoResponse.from_response(local_response, models.NodeAddOnResource)

    def get_node_add_on_products(
        self,
    ) -> DtoResponse[list[models.NodeAddOnProduct]]:
        local_response = self.api_connector.send_or_fail(
            "GET", "/api/v1/node-add-ons/products", data=None, query_parameters={}
        )

        return DtoResponse.from_response(local_response, models.NodeAddOnProduct)

    def read_node_add_on(
        self,
        *,
        id_: int,
    ) -> DtoResponse[models.NodeAddOnResource]:
        local_response = self.api_connector.send_or_fail(
            "GET", f"/api/v1/node-add-ons/{id_}", data=None, query_parameters={}
        )

        return DtoResponse.from_response(local_response, models.NodeAddOnResource)

    def delete_node_add_on(
        self,
        *,
        id_: int,
        callback_url: Optional[str] = None,
    ) -> DtoResponse[models.TaskCollectionResource]:
        local_response = self.api_connector.send_or_fail(
            "DELETE",
            f"/api/v1/node-add-ons/{id_}",
            data=None,
            query_parameters={
                "callback_url": callback_url,
            },
        )

        return DtoResponse.from_response(local_response, models.TaskCollectionResource)
